# VK2TELEGRAPH [![PyPI](https://img.shields.io/pypi/pyversions/vk2telegraph.svg?style=plastic)](https://github.com/kristaller486/vk2telegraph)

_A simple script that publishes articles from VK in Telegra.ph_

## Installation

To install vk2telegraph with pip, run: `pip install vk2telegraph`

## Usage

You can create telegra.ph arcticle:
```bash
python -m vk2telegraph [url]
```

For example

```bash
python -m vk2telegraph https://vk.com/@sample-article
```

## License

Licensed under the
[MIT](https://github.com/kristaller486/vk2telegraph/blob/main/LICENSE) License.
